Check columns of two data frames match Easily check to make sure data frames have the same columns, no matter the order. check_cols returns nothing unless there is a mismatch, in which it throws an error. It does not check attributes or class.
check_cols.RdCheck columns of two data frames match
Easily check to make sure data frames have the same columns, no matter the
order. check_cols returns nothing unless there is a mismatch, in which it
throws an error. It does not check attributes or class.