Changes between two data frames
compares.RdCompares two data frames df_old and df_new.These functions were originally
intended for syncing a remote data source with a local one, but generally
work for comparing any data frames.
new_vals(df_old, df_new, key)finds all of the rows with a value in the key column indf_newthat is not indf_oldchanged_vals(df_old, df_new, key)finds all of the rows that have the same value in the key column but different data in the other columnsold_vals(df_old, df_new, key)finds all of the rows with a value in the key column indf_oldthat is not indf_new